@@ -26,38 +26,15 @@ class InstallpathModel(BaseModel):
     List of install paths in the form of:
     ('UI Text seen by user', <signal name>, <callback function string>)
     """
-    signals = [
-        ('Install Path View',
-         'menu:installpath:main',
-         'installpath')
-    ]
 
     # TODO: Re-enable once available
     install_paths = [
-        ('Install Ubuntu',
-         'installpath:install-ubuntu',
-         'install_ubuntu'),
-        # ('Install MAAS Region Server',
-        #  'installpath:maas-region-server',
-        #  'install_maas_region_server'),
-        # ('Install MAAS Cluster Server',
-        #  'installpath:maas-cluster-server',
-        #  'install_maas_cluster_server'),
-        # ('Test installation media',
-        #  'installpath:test-media',
-        #  'test_media'),
-        # ('Test machine memory',
-        #  'installpath:test-memory',
-        #  'test_memory')
+        ('Install Ubuntu',               'installpath:install-ubuntu'),
+        # ('Install MAAS Region Server',  'installpath:maas-region-server'),
+        # ('Install MAAS Cluster Server', 'installpath:maas-cluster-server'),
+        # ('Test installation media',     'installpath:test-media'),
+        # ('Test machine memory',         'installpath:test-memory')
     ]
 
-    def get_signal_by_name(self, selection):
-        for x, y, z in self.get_signals():
-            if x == selection:
-                return y
-
-    def get_signals(self):
-        return self.signals + self.install_paths
-
     def get_menu(self):
         return self.install_paths
